<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>AboutDialog</name>
    <message>
        <source>Qt Linguist</source>
        <translation>Qt Linguist</translation>
    </message>
</context>
<context>
    <name>BatchTranslationDialog</name>
    <message numerus="yes">
        <source>Batch translated %n entries</source>
        <translation>
            <numerusform>Automat przetłumaczył %n wpis</numerusform>
            <numerusform>Automat przetłumaczył %n wpisy</numerusform>
            <numerusform>Automat przetłumaczył %n wpisów</numerusform>
        </translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Anuluj</translation>
    </message>
    <message>
        <source>Batch Translation of &apos;%1&apos; - Qt Linguist</source>
        <translation>Automatyczne tłumaczenie &apos;%1&apos; - Qt Linguist</translation>
    </message>
    <message>
        <source>Linguist batch translator</source>
        <translation>Zautomatyzowany tłumacz Linguist&apos;a</translation>
    </message>
    <message>
        <source>Searching, please wait...</source>
        <translation>Przeszukiwanie, proszę czekać...</translation>
    </message>
    <message>
        <source>Qt Linguist - Batch Translation</source>
        <translation>Qt Linguist - automatyczne tłumaczenie</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opcje</translation>
    </message>
    <message>
        <source>Set translated entries to finished</source>
        <translation>Ustaw przetłumaczone wpisy jako ukończone</translation>
    </message>
    <message>
        <source>Retranslate entries with existing translation</source>
        <translation>Przetłumacz wpisy z istniejącymi tłumaczeniami</translation>
    </message>
    <message>
        <source>Translate also finished entries</source>
        <translation>Przetłumacz również ukończone wpisy</translation>
    </message>
    <message>
        <source>Phrase book preference</source>
        <translation>Ustawienia książki wyrażeń</translation>
    </message>
    <message>
        <source>Move up</source>
        <translation>Przenieś do góry</translation>
    </message>
    <message>
        <source>Move down</source>
        <translation>Przenieś w dół</translation>
    </message>
    <message>
        <source>&amp;Run</source>
        <translation>&amp;Uruchom</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <source>Note that the modified entries will be reset to unfinished if &apos;Set translated entries to finished&apos; above is unchecked</source>
        <translation>Zwróć uwagę że zmodyfikowane wpisy będą ustawione jako nieukończone jeśli znajdujące się powyżej &apos;Ustaw przetłumaczone wpisy jako ukończone&apos; nie jest zaznaczone</translation>
    </message>
    <message>
        <source>The batch translator will search through the selected phrase books in the order given above</source>
        <translation>Automatyczny tłumacz będzie przeszukiwał wybrane książki wyrażeń w porządku ustalonym powyżej</translation>
    </message>
</context>
<context>
    <name>DataModel</name>
    <message>
        <source>The translation file &apos;%1&apos; will not be loaded because it is empty.</source>
        <translation>Plik z tłumaczeniami &quot;%1&quot; nie zostanie załadowany ponieważ jest pusty.</translation>
    </message>
    <message>
        <source>&lt;qt&gt;Duplicate messages found in &apos;%1&apos;:</source>
        <translation>&lt;qt&gt;Znaleziono powtórzenia w &apos;%1&apos;:</translation>
    </message>
    <message>
        <source>&lt;p&gt;[more duplicates omitted]</source>
        <translation>&lt;p&gt;[pominięto resztę powtórzeń]</translation>
    </message>
    <message>
        <source>&lt;p&gt;* ID: %1</source>
        <translation>&lt;p&gt;* identyfikator: %1</translation>
    </message>
    <message>
        <source>&lt;p&gt;* Context: %1&lt;br&gt;* Source: %2</source>
        <translation>&lt;p&gt;* Kontekst: %1&lt;br&gt;* Źródło: %2</translation>
    </message>
    <message>
        <source>&lt;br&gt;* Comment: %3</source>
        <translation>&lt;br&gt;* Komentarz: %3</translation>
    </message>
    <message>
        <source>Linguist does not know the plural rules for &apos;%1&apos;.
Will assume a single universal form.</source>
        <translation>Linguist nie zna reguł liczby mnogiej dla &quot;%1&quot;.
Przyjmie on uniwersalną formę liczby pojedynczej.</translation>
    </message>
    <message>
        <source>Cannot create &apos;%2&apos;: %1</source>
        <translation>Nie można utworzyć &apos;%2&apos;: %1</translation>
    </message>
    <message>
        <source>Universal Form</source>
        <translation>Forma uniwersalna</translation>
    </message>
</context>
<context>
    <name>ErrorsView</name>
    <message>
        <source>Accelerator possibly superfluous in translation.</source>
        <translation>Prawdopodobnie nadmiarowy klawisz skrótu w tłumaczeniu.</translation>
    </message>
    <message>
        <source>Accelerator possibly missing in translation.</source>
        <translation>Prawdopodobnie brakuje klawisza skrótu w tłumaczeniu.</translation>
    </message>
    <message>
        <source>Translation does not end with the same punctuation as the source text.</source>
        <translation>Tłumaczenie nie kończy się tym samym znakiem interpunkcyjnym co tekst źródłowy.</translation>
    </message>
    <message>
        <source>A phrase book suggestion for &apos;%1&apos; was ignored.</source>
        <translation>Podpowiedź &apos;%1&apos; z książki wyrażeń została zignorowana.</translation>
    </message>
    <message>
        <source>Translation does not refer to the same place markers as in the source text.</source>
        <translation>Tłumaczenie nie zawiera tych samych znaczników co tekst źródłowy.</translation>
    </message>
    <message>
        <source>Translation does not contain the necessary %n place marker.</source>
        <translation>Tłumaczenie nie zawiera koniecznego znacznika %n.</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Nieznany błąd</translation>
    </message>
</context>
<context>
    <name>FindDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <source>Click here to close this window.</source>
        <translation>Kliknij tutaj aby zamknąć to okno.</translation>
    </message>
    <message>
        <source>Click here to find the next occurrence of the text you typed in.</source>
        <translation>Kliknij tutaj aby znaleźć następne wystąpienie szukanego tekstu.</translation>
    </message>
    <message>
        <source>Comments and contexts are searched when checked.</source>
        <translation>Jeśli zaznaczone, przeszukuje także komentarze i konteksty.</translation>
    </message>
    <message>
        <source>Find Next</source>
        <translation>Znajdź następny</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opcje</translation>
    </message>
    <message>
        <source>Source texts are searched when checked.</source>
        <translation>Jeśli zaznaczone przeszukuje także teksty źródłowe.</translation>
    </message>
    <message>
        <source>Texts such as &apos;TeX&apos; and &apos;tex&apos; are considered as different when checked.</source>
        <translation>Jeśli zaznaczone, teksty &apos;TeX&apos; oraz &apos;tex&apos; są interpretowane jako różne.</translation>
    </message>
    <message>
        <source>This window allows you to search for some text in the translation source file.</source>
        <translation>Pozwala na szukanie w językowym pliku źródłowym.</translation>
    </message>
    <message>
        <source>Translations are searched when checked.</source>
        <translation>Jeśli zaznaczone, przeszukuje także tłumaczenia.</translation>
    </message>
    <message>
        <source>Type in the text to search for.</source>
        <translation>Wprowadź tekst do wyszukania.</translation>
    </message>
    <message>
        <source>Find</source>
        <translation>Znajdź</translation>
    </message>
    <message>
        <source>&amp;Find what:</source>
        <translation>&amp;Znajdź:</translation>
    </message>
    <message>
        <source>&amp;Source texts</source>
        <translation>Teksty ź&amp;ródłowe</translation>
    </message>
    <message>
        <source>&amp;Translations</source>
        <translation>&amp;Tłumaczenia</translation>
    </message>
    <message>
        <source>&amp;Match case</source>
        <translation>Uwzględniaj &amp;wielkość liter</translation>
    </message>
    <message>
        <source>&amp;Comments</source>
        <translation>&amp;Komentarze</translation>
    </message>
    <message>
        <source>Ignore &amp;accelerators</source>
        <translation>Ignoruj kl&amp;awisze skrótów</translation>
    </message>
    <message>
        <source></source>
        <comment>Choose Edit|Find from the menu bar or press Ctrl+F to pop up the Find dialog</comment>
        <translation></translation>
    </message>
    <message>
        <source>Obsoleted messages are skipped when checked.</source>
        <translation>Pomija zdezaktualizowane wyrażenia.</translation>
    </message>
    <message>
        <source>Skip &amp;obsolete</source>
        <translation>P&amp;omiń zdezaktualizowane</translation>
    </message>
</context>
<context>
    <name>FormMultiWidget</name>
    <message>
        <source>Alt+Delete</source>
        <extracomment>translate, but don&apos;t change</extracomment>
        <translation>Alt+Delete</translation>
    </message>
    <message>
        <source>Shift+Alt+Insert</source>
        <extracomment>translate, but don&apos;t change</extracomment>
        <translation>Shift+Alt+Insert</translation>
    </message>
    <message>
        <source>Alt+Insert</source>
        <extracomment>translate, but don&apos;t change</extracomment>
        <translation>Alt+Insert</translation>
    </message>
    <message>
        <source>Confirmation - Qt Linguist</source>
        <translation>Potwierdzenie - Qt Linguist</translation>
    </message>
    <message>
        <source>Delete non-empty length variant?</source>
        <translation>Skasować niepusty wariant?</translation>
    </message>
</context>
<context>
    <name>LRelease</name>
    <message numerus="yes">
        <source>Dropped %n message(s) which had no ID.</source>
        <translation>
            <numerusform>Opuszczono %n wyrażenie które nie miało identyfikatora.</numerusform>
            <numerusform>Opuszczono %n wyrażenia które nie miały identyfikatorów.</numerusform>
            <numerusform>Opuszczono %n wyrażeń które nie miały identyfikatorów.</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>Excess context/disambiguation dropped from %n message(s).</source>
        <translation>
            <numerusform>Opuszczono nadmiarowy kontekst/ujednoznacznienie w %n wyrażeniu.</numerusform>
            <numerusform>Opuszczono nadmiarowe konteksty/ujednoznacznienia w %n wyrażeniach.</numerusform>
            <numerusform>Opuszczono nadmiarowe konteksty/ujednoznacznienia w %n wyrażeniach.</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>    Generated %n translation(s) (%1 finished and %2 unfinished)</source>
        <translation>
            <numerusform>    Wygenerowano %n tłumaczenie (przetłumaczonych %1, nieprzetłumaczonych %2)</numerusform>
            <numerusform>    Wygenerowano %n tłumaczenia (przetłumaczonych %1, nieprzetłumaczonych %2)</numerusform>
            <numerusform>    Wygenerowano %n tłumaczeń (przetłumaczonych %1, nieprzetłumaczonych %2)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>    Ignored %n untranslated source text(s)</source>
        <translation>
            <numerusform>    Pominięto %n nieprzetłumaczony tekst źródłowy￼</numerusform>
            <numerusform>    Pominięto %n nieprzetłumaczone teksty źródłowe</numerusform>
            <numerusform>    Pominięto %n nieprzetłumaczonych tekstów źródłowy￼ch</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>Linguist</name>
    <message>
        <source>GNU Gettext localization files</source>
        <translation>Pliki GNU Gettext</translation>
    </message>
    <message>
        <source>GNU Gettext localization template files</source>
        <translation>Szablony plików GNU Gettext</translation>
    </message>
    <message>
        <source>Compiled Qt translations</source>
        <translation>Skompilowane tłumaczenia Qt</translation>
    </message>
    <message>
        <source>Qt Linguist &apos;Phrase Book&apos;</source>
        <translation>&quot;Książka wyrażeń&quot; Qt Linguista</translation>
    </message>
    <message>
        <source>Qt translation sources</source>
        <translation>Źródła tłumaczeń Qt</translation>
    </message>
    <message>
        <source>XLIFF localization files</source>
        <translation>Pliki XLIFF</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>About Qt</source>
        <translation>Informacje o Qt</translation>
    </message>
    <message>
        <source>About Qt Linguist</source>
        <translation>Informacje o Qt Linguist</translation>
    </message>
    <message>
        <source>&amp;Accelerators</source>
        <translation>Klawisze &amp;skrótów</translation>
    </message>
    <message>
        <source>Batch translate all entries using the information in the phrase books.</source>
        <translation>Automatycznie tłumaczy wszystkie wpisy używając książek wyrażeń.</translation>
    </message>
    <message>
        <source>&amp;Close Phrase Book</source>
        <translation>&amp;Zamknij książkę wyrażeń</translation>
    </message>
    <message>
        <source>Close this window and exit.</source>
        <translation>Zamknij okno i zakończ program.</translation>
    </message>
    <message>
        <source>Continue the search where it was left.</source>
        <translation>Kontynuuj przeszukiwanie od miejsca gdzie je zatrzymano.</translation>
    </message>
    <message>
        <source>Copies the source text into the translation field.</source>
        <translation>Kopiuje tekst źródłowy do pola z tłumaczeniem.</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>S&amp;kopiuj</translation>
    </message>
    <message>
        <source>Copy the selected translation text to the clipboard.</source>
        <translation>Skopiuj zaznaczony tekst do schowka.</translation>
    </message>
    <message>
        <source>Copy the selected translation text to the clipboard and deletes it.</source>
        <translation>Skopiuj zaznaczony tekst do schowka i usuń go.</translation>
    </message>
    <message>
        <source>Create a new phrase book.</source>
        <translation>Utwórz nową książkę wyrażeń.</translation>
    </message>
    <message>
        <source>Create a Qt message file suitable for released applications from the current message file.</source>
        <translation>Utwórz binarny plik z tłumaczeniami na podstawie bieżącego tłumaczenia, gotowy do użycia w aplikacjach.</translation>
    </message>
    <message>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <source>Ctrl+B</source>
        <translation>Ctrl+B</translation>
    </message>
    <message>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation>Ctrl+H</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>Open Read-O&amp;nly...</source>
        <translation>Otwórz tylko do od&amp;czytu...</translation>
    </message>
    <message>
        <source>&amp;Save All</source>
        <translation>Zapisz &amp;wszystko</translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <source>Ctrl+Shift+K</source>
        <translation>Ctrl+Shift+K</translation>
    </message>
    <message>
        <source>Ctrl+V</source>
        <translation>Ctrl+V</translation>
    </message>
    <message>
        <source>Ctrl+X</source>
        <translation>Ctrl+X</translation>
    </message>
    <message>
        <source>Ctrl+Y</source>
        <translation>Ctrl+Y</translation>
    </message>
    <message>
        <source>Ctrl+Z</source>
        <translation>Ctrl+Z</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation>Wy&amp;tnij</translation>
    </message>
    <message>
        <source>&amp;Display guesses</source>
        <translation>Pokaż &amp;podpowiedzi</translation>
    </message>
    <message>
        <source>&amp;Done and Next</source>
        <translation>&amp;Zrobione i do następnego</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Edycja</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Edycja</translation>
    </message>
    <message>
        <source>&amp;Edit Phrase Book</source>
        <translation>&amp;Redaguj książkę wyrażeń</translation>
    </message>
    <message>
        <source>&amp;Ending Punctuation</source>
        <translation>Za&amp;kończenia interpunkcyjne</translation>
    </message>
    <message>
        <source>Enter What&apos;s This? mode.</source>
        <translation>Wejdź do trybu &quot;Co to jest?&quot;.</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>Za&amp;kończ</translation>
    </message>
    <message>
        <source>F1</source>
        <translation>F1</translation>
    </message>
    <message>
        <source>F3</source>
        <translation>F3</translation>
    </message>
    <message>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Plik</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Plik</translation>
    </message>
    <message>
        <source>Find &amp;Next</source>
        <translation>Znajdź &amp;następny</translation>
    </message>
    <message>
        <source>Form Preview Tool</source>
        <translation>Podgląd formularzy</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Pomoc</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>P&amp;omoc</translation>
    </message>
    <message>
        <source>MainWindow</source>
        <translation>Okno główne</translation>
    </message>
    <message>
        <source>&amp;Manual</source>
        <translation>Pod&amp;ręcznik</translation>
    </message>
    <message>
        <source>Ne&amp;xt</source>
        <translation>N&amp;astępne</translation>
    </message>
    <message>
        <source>&amp;Next Unfinished</source>
        <translation>&amp;Następne nieukończone</translation>
    </message>
    <message>
        <source>Open a phrase book to assist translation.</source>
        <translation>Otwórz książkę wyrażeń pomocną przy tłumaczeniu.</translation>
    </message>
    <message>
        <source>Open a Qt translation source file (TS file) for editing</source>
        <translation>Otwórz plik z tłumaczeniami Qt (plik TS) do redagowania</translation>
    </message>
    <message>
        <source>Open/Refresh Form &amp;Preview</source>
        <translation>Otwórz/odśwież &amp;podgląd formularzy</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation>Wk&amp;lej</translation>
    </message>
    <message>
        <source>Paste the clipboard text into the translation.</source>
        <translation>Wklej tekst ze schowka do pola z tłumaczeniem.</translation>
    </message>
    <message>
        <source>&amp;Phrase matches</source>
        <translation>&amp;Cudzysłowy</translation>
    </message>
    <message>
        <source>&amp;Phrases</source>
        <translation>W&amp;yrażenia</translation>
    </message>
    <message>
        <source>Place &amp;Marker Matches</source>
        <translation>Z&amp;naczniki</translation>
    </message>
    <message>
        <source>P&amp;rev</source>
        <translation>P&amp;oprzednie</translation>
    </message>
    <message>
        <source>&amp;Prev Unfinished</source>
        <translation>&amp;Poprzednie nieukończone</translation>
    </message>
    <message>
        <source>&amp;Print Phrase Book</source>
        <translation>Wy&amp;drukuj książkę wyrażeń</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>&amp;Przywróć</translation>
    </message>
    <message>
        <source>Redo an undone editing operation performed on the translation.</source>
        <translation>Przywróć ostatnio cofniętą zmianę w tłumaczeniach.</translation>
    </message>
    <message>
        <source>&amp;Release</source>
        <translation>W&amp;ydaj</translation>
    </message>
    <message>
        <source>Release As...</source>
        <translation>Wydaj jako...</translation>
    </message>
    <message>
        <source>Replace the translation on all entries that matches the search source text.</source>
        <translation>Zamienia tłumaczenia we wszystkich pasujących do wzorca wpisach.</translation>
    </message>
    <message>
        <source></source>
        <comment>This is the application&apos;s main window.</comment>
        <translation></translation>
    </message>
    <message>
        <source>Source text</source>
        <translation>Tekst źródłowy</translation>
    </message>
    <message>
        <source>Index</source>
        <translation>Indeks</translation>
    </message>
    <message>
        <source>Context</source>
        <translation>Kontekst</translation>
    </message>
    <message>
        <source>Items</source>
        <translation>Elementy</translation>
    </message>
    <message>
        <source>This panel lists the source contexts.</source>
        <translation>Ten panel pokazuje listę kontekstów.</translation>
    </message>
    <message>
        <source>Strings</source>
        <translation>Tłumaczenia</translation>
    </message>
    <message>
        <source>Phrases and guesses</source>
        <translation>Wyrażenia i podpowiedzi</translation>
    </message>
    <message>
        <source>Sources and Forms</source>
        <translation>Źródła i formularze</translation>
    </message>
    <message>
        <source>Warnings</source>
        <translation>Ostrzeżenia</translation>
    </message>
    <message>
        <source> MOD </source>
        <comment>status bar: file(s) modified</comment>
        <translation> MOD </translation>
    </message>
    <message>
        <source>Loading...</source>
        <translation>Ładowanie...</translation>
    </message>
    <message>
        <source>Loading File - Qt Linguist</source>
        <translation>Wczytywanie pliku - Qt Linguist</translation>
    </message>
    <message>
        <source>The file &apos;%1&apos; does not seem to be related to the currently open file(s) &apos;%2&apos;.

Close the open file(s) first?</source>
        <translation>Plik &apos;%1&apos; nie wygląda na związany z otwartym już plikiem (plikami) &apos;%2&apos;.

Czy chcesz najpierw zamknąć otwarty plik (pliki)?</translation>
    </message>
    <message>
        <source>The file &apos;%1&apos; does not seem to be related to the file &apos;%2&apos; which is being loaded as well.

Skip loading the first named file?</source>
        <translation>Plik &apos;%1&apos; również nie wygląda na związany z otwieranym właśnie plikiem &apos;%2&apos;.

Czy chcesz pominąć pierwszy plik?</translation>
    </message>
    <message numerus="yes">
        <source>%n translation unit(s) loaded.</source>
        <translation>
            <numerusform>Załadowano %n część z tłumaczeniami.</numerusform>
            <numerusform>Załadowano %n części z tłumaczeniami.</numerusform>
            <numerusform>Załadowano %n części z tłumaczeniami.</numerusform>
        </translation>
    </message>
    <message>
        <source>Related files (%1);;</source>
        <translation>Związane pliki (%1);;</translation>
    </message>
    <message>
        <source>Open Translation Files</source>
        <translation>Otwórz pliki z tłumaczeniami</translation>
    </message>
    <message>
        <source>File saved.</source>
        <translation>Plik zachowany.</translation>
    </message>
    <message>
        <source>Release</source>
        <translation>Wydaj</translation>
    </message>
    <message>
        <source>Qt message files for released applications (*.qm)
All files (*)</source>
        <translation>Pliki z wydanymi tłumaczeniami (*.qm)
Wszystkie pliki (*)</translation>
    </message>
    <message>
        <source>File created.</source>
        <translation>Plik utworzony.</translation>
    </message>
    <message>
        <source>Printing...</source>
        <translation>Drukowanie...</translation>
    </message>
    <message>
        <source>Context: %1</source>
        <translation>Kontekst: %1</translation>
    </message>
    <message>
        <source>finished</source>
        <translation>zakończony</translation>
    </message>
    <message>
        <source>unresolved</source>
        <translation>nierozwiązany</translation>
    </message>
    <message>
        <source>obsolete</source>
        <translation>zdezaktualizowany</translation>
    </message>
    <message>
        <source>Printing... (page %1)</source>
        <translation>Drukowanie...(strona %1)</translation>
    </message>
    <message>
        <source>Printing completed</source>
        <translation>Drukowanie zakończone</translation>
    </message>
    <message>
        <source>Printing aborted</source>
        <translation>Drukowanie przerwane</translation>
    </message>
    <message>
        <source>Search wrapped.</source>
        <translation>Szukanie od początku.</translation>
    </message>
    <message>
        <source>Qt Linguist</source>
        <translation>Qt Linguist</translation>
    </message>
    <message>
        <source>Cannot find the string &apos;%1&apos;.</source>
        <translation>Nie można znaleźć tekstu &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>Search And Translate in &apos;%1&apos; - Qt Linguist</source>
        <translation>Wyszukiwanie i tłumaczenie w &apos;%1&apos; - Qt Linguist</translation>
    </message>
    <message>
        <source>Translate - Qt Linguist</source>
        <translation>Tłumaczenie - Qt Linguist</translation>
    </message>
    <message numerus="yes">
        <source>Translated %n entry(s)</source>
        <translation>
            <numerusform>Przetłumaczono %n wpis</numerusform>
            <numerusform>Przetłumaczono %n wpisy</numerusform>
            <numerusform>Przetłumaczono %n wpisów</numerusform>
        </translation>
    </message>
    <message>
        <source>No more occurrences of &apos;%1&apos;. Start over?</source>
        <translation>Brak więcej &quot;%1&quot;. Rozpocząć od nowa?</translation>
    </message>
    <message>
        <source>Create New Phrase Book</source>
        <translation>Utwórz nową książkę wyrażeń</translation>
    </message>
    <message>
        <source>Qt phrase books (*.qph)
All files (*)</source>
        <translation>Książki wyrażeń Qt (*.qph)
Wszystkie pliki (*)</translation>
    </message>
    <message>
        <source>Phrase book created.</source>
        <translation>Utworzono podręcznik wyrażeń.</translation>
    </message>
    <message>
        <source>Open Phrase Book</source>
        <translation>Otwórz książkę wyrażeń</translation>
    </message>
    <message>
        <source>Qt phrase books (*.qph);;All files (*)</source>
        <translation>Książki wyrażeń Qt (*.qph);;Wszystkie pliki (*)</translation>
    </message>
    <message numerus="yes">
        <source>%n phrase(s) loaded.</source>
        <translation>
            <numerusform>Wczytano %n wyrażenie.</numerusform>
            <numerusform>Wczytano %n wyrażenia.</numerusform>
            <numerusform>Wczytano %n wyrażeń.</numerusform>
        </translation>
    </message>
    <message>
        <source>Add to phrase book</source>
        <translation>Dodaj do książki wyrażeń</translation>
    </message>
    <message>
        <source>No appropriate phrasebook found.</source>
        <translation>Brak odpowiedniej książki wyrażeń.</translation>
    </message>
    <message>
        <source>Adding entry to phrasebook %1</source>
        <translation>Dodawanie wpisu do książki wyrażeń %1</translation>
    </message>
    <message>
        <source>Select phrase book to add to</source>
        <translation>Wybierz książkę do której chcesz dodać</translation>
    </message>
    <message>
        <source>Unable to launch Qt Assistant (%1)</source>
        <translation>Nie można uruchomić Qt Assistant (%1)</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>Wersja %1</translation>
    </message>
    <message>
        <source>&lt;center&gt;&lt;img src=&quot;:/images/splash.png&quot;/&gt;&lt;/img&gt;&lt;p&gt;%1&lt;/p&gt;&lt;/center&gt;&lt;p&gt;Qt Linguist is a tool for adding translations to Qt applications.&lt;/p&gt;&lt;p&gt;Copyright (C) %2 The Qt Company Ltd.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do you want to save the modified files?</source>
        <translation>Czy chcesz zachować zmodyfikowane pliki?</translation>
    </message>
    <message>
        <source>Do you want to save &apos;%1&apos;?</source>
        <translation>Czy chcesz zachować &apos;%1&apos;?</translation>
    </message>
    <message>
        <source>Qt Linguist[*]</source>
        <translation>Qt Linguist[*]</translation>
    </message>
    <message>
        <source>%1[*] - Qt Linguist</source>
        <translation>%1[*] - Qt Linguist</translation>
    </message>
    <message>
        <source>No untranslated translation units left.</source>
        <translation>Wszystkie wyrażenia są przetłumaczone.</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Okno</translation>
    </message>
    <message>
        <source>Minimize</source>
        <translation>Zminimalizuj</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>Display the manual for %1.</source>
        <translation>Pokaż podręcznik dla %1.</translation>
    </message>
    <message>
        <source>Display information about %1.</source>
        <translation>Pokaż informacje o %1.</translation>
    </message>
    <message>
        <source>&amp;Save &apos;%1&apos;</source>
        <translation>&amp;Zachowaj &apos;%1&apos;</translation>
    </message>
    <message>
        <source>Save &apos;%1&apos; &amp;As...</source>
        <translation>Zachowaj &apos;%1&apos; &amp;jako...</translation>
    </message>
    <message>
        <source>Release &apos;%1&apos;</source>
        <translation>Wydaj &apos;%1&apos;</translation>
    </message>
    <message>
        <source>Release &apos;%1&apos; As...</source>
        <translation>Wydaj &apos;%1&apos; jako...</translation>
    </message>
    <message>
        <source>&amp;Close &apos;%1&apos;</source>
        <translation>Za&amp;mknij &apos;%1&apos;</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Zachowaj</translation>
    </message>
    <message>
        <source>Save &amp;As...</source>
        <translation>Zachowaj j&amp;ako...</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>Za&amp;mknij</translation>
    </message>
    <message>
        <source>Save All</source>
        <translation>Zachowaj wszystko</translation>
    </message>
    <message>
        <source>&amp;Release All</source>
        <translation>Wydaj &amp;wszystko</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>Zamknij wszystko</translation>
    </message>
    <message>
        <source>Translation File &amp;Settings for &apos;%1&apos;...</source>
        <translation>&amp;Ustawienia pliku z tłumaczeniami dla &apos;%1&apos;...</translation>
    </message>
    <message>
        <source>&amp;Batch Translation of &apos;%1&apos;...</source>
        <translation>&amp;Automatyczne tłumaczenie &apos;%1&apos;...</translation>
    </message>
    <message>
        <source>Search And &amp;Translate in &apos;%1&apos;...</source>
        <translation>Wyszukiwanie i &amp;tłumaczenie w &apos;%1&apos;...</translation>
    </message>
    <message>
        <source>Search And &amp;Translate...</source>
        <translation>Wyszukiwanie i &amp;tłumaczenie...</translation>
    </message>
    <message>
        <source>Cannot read from phrase book &apos;%1&apos;.</source>
        <translation>Nie można odczytać z książki wyrażeń &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>Close this phrase book.</source>
        <translation>Zamknij tę książkę wyrażeń.</translation>
    </message>
    <message>
        <source>Enables you to add, modify, or delete entries in this phrase book.</source>
        <translation>Pozwala na dodawanie, modyfikowanie i usuwanie wpisów w tej książce.</translation>
    </message>
    <message>
        <source>Print the entries in this phrase book.</source>
        <translation>Wydrukuj wpisy z książki wyrażeń.</translation>
    </message>
    <message>
        <source>Cannot create phrase book &apos;%1&apos;.</source>
        <translation>Nie można utworzyć książki wyrażeń &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>Do you want to save phrase book &apos;%1&apos;?</source>
        <translation>Czy chcesz zachować książke wyrażeń &apos;%1&apos;?</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Wszystko</translation>
    </message>
    <message>
        <source>Save As...</source>
        <translation>Zachowaj jako...</translation>
    </message>
    <message>
        <source>Save changes made to this Qt translation source file</source>
        <translation>Zachowaj wprowadzone zmiany w tym pliku z tłumaczeniami</translation>
    </message>
    <message>
        <source>Save changes made to this Qt translation source file into a new file.</source>
        <translation>Zachowaj wprowadzone zmiany w tym pliku z tłumaczeniami jako nowy plik.</translation>
    </message>
    <message>
        <source>Search for some text in the translation source file.</source>
        <translation>Szukaj tekstu w pliku z tłumaczeniem.</translation>
    </message>
    <message>
        <source>Select &amp;All</source>
        <translation>Zaznacz &amp;wszystko</translation>
    </message>
    <message>
        <source>Select the whole translation text.</source>
        <translation>Zaznacz cały tekst tłumaczenia.</translation>
    </message>
    <message>
        <source>Set whether or not to display translation guesses.</source>
        <translation>Ustaw czy pokazywać podpowiedzi tłumaczeń.</translation>
    </message>
    <message>
        <source>Shift+F1</source>
        <translation>Shift+F1</translation>
    </message>
    <message>
        <source>Sort the items back in the same order as in the message file.</source>
        <translation>Z powrotem sortuj elementy w takiej samej kolejności jak w pliku źródłowym.</translation>
    </message>
    <message>
        <source>&amp;Statistics</source>
        <translation>&amp;Statystyki</translation>
    </message>
    <message>
        <source>&amp;Toolbars</source>
        <translation>Paski &amp;narzędzi</translation>
    </message>
    <message>
        <source>&amp;Translation</source>
        <translation>&amp;Tłumaczenie</translation>
    </message>
    <message>
        <source>Translation</source>
        <translation>Tłumaczenie</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>&amp;Cofnij</translation>
    </message>
    <message>
        <source>Validation</source>
        <translation>Walidacja</translation>
    </message>
    <message>
        <source>V&amp;alidation</source>
        <translation>W&amp;alidacja</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Widok</translation>
    </message>
    <message>
        <source>Vie&amp;ws</source>
        <translation>&amp;Widoki</translation>
    </message>
    <message>
        <source>&amp;What&apos;s This?</source>
        <translation>&amp;Co to jest?</translation>
    </message>
    <message>
        <source>What&apos;s This?</source>
        <translation>Co to jest?</translation>
    </message>
    <message>
        <source>&amp;Open...</source>
        <translation>&amp;Otwórz...</translation>
    </message>
    <message>
        <source>&amp;Print...</source>
        <translation>Wy&amp;drukuj...</translation>
    </message>
    <message>
        <source>&amp;Find...</source>
        <translation>&amp;Znajdź...</translation>
    </message>
    <message>
        <source>Toggle the validity check of ending punctuation. If the check fails, a message is shown in the warnings window.</source>
        <translation>Przełącz sprawdzanie zgodności końcowych znaków interpunkcyjnych. W przypadku niezgodności pojawia się komunikat w oknie z ostrzeżeniami.</translation>
    </message>
    <message>
        <source>&amp;New Phrase Book...</source>
        <translation>&amp;Nowa książka wyrażeń...</translation>
    </message>
    <message>
        <source>&amp;Open Phrase Book...</source>
        <translation>&amp;Otwórz książkę wyrażeń...</translation>
    </message>
    <message>
        <source>&amp;Reset Sorting</source>
        <translation>Wyłącz so&amp;rtowanie</translation>
    </message>
    <message>
        <source>Display translation statistics.</source>
        <translation>Pokaż statystyki tłumaczeń.</translation>
    </message>
    <message>
        <source>&amp;Search And Translate...</source>
        <translation>Wy&amp;szukiwanie i tłumaczenie...</translation>
    </message>
    <message>
        <source>&amp;Batch Translation...</source>
        <translation>Automatyczne &amp;tłumaczenie...</translation>
    </message>
    <message>
        <source>Translation File &amp;Settings...</source>
        <translation>&amp;Ustawienia pliku z tłumaczeniami...</translation>
    </message>
    <message>
        <source>&amp;Add to Phrase Book</source>
        <translation>Dod&amp;aj do książki wyrażeń</translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <source>Recently Opened &amp;Files</source>
        <translation>Os&amp;tatnio otwierane pliki</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Zachowaj</translation>
    </message>
    <message>
        <source>Print a list of all the translation units in the current translation source file.</source>
        <translation>Wydrukuj pełną listę wyrażeń z bieżącego pliku z tłumaczeniami.</translation>
    </message>
    <message>
        <source>Undo the last editing operation performed on the current translation.</source>
        <translation>Cofnij ostatnio wykonaną zmianę w bieżącym tłumaczeniu.</translation>
    </message>
    <message>
        <source>Move to the previous unfinished item.</source>
        <translation>Przechodzi do poprzedniego nieukończonego elementu.</translation>
    </message>
    <message>
        <source>Move to the next unfinished item.</source>
        <translation>Przechodzi do następnego nieukończonego elementu.</translation>
    </message>
    <message>
        <source>Move to the previous item.</source>
        <translation>Przejdź do poprzedniego elementu.</translation>
    </message>
    <message>
        <source>Move to the next item.</source>
        <translation>Przejdź do następnego elementu.</translation>
    </message>
    <message>
        <source>Mark this item as done and move to the next unfinished item.</source>
        <translation>Oznacz ten element jako ukończony i przejdź do następnego nieukończonego elementu.</translation>
    </message>
    <message>
        <source>Copy from source text</source>
        <translation>Skopiuj ze źródła tekstu</translation>
    </message>
    <message>
        <source>Toggle the validity check of accelerators, i.e. whether the number of ampersands in the source and translation text is the same. If the check fails, a message is shown in the warnings window.</source>
        <translation>Przełącz sprawdzanie zgodności klawiszy skrótów, tzn. czy liczba znaków: &amp; w tekście źródłowym i w tłumaczeniu jest taka sama. W przypadku niezgodności pojawia się komunikat w oknie z ostrzeżeniami.</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zamknij</translation>
    </message>
    <message>
        <source>&amp;Close All</source>
        <translation>Zam&amp;knij wszystko</translation>
    </message>
    <message>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <source>Toggle checking that phrase suggestions are used. If the check fails, a message is shown in the warnings window.</source>
        <translation>Przełącz sprawdzanie czy użyto zasugerowanego wyrażenia. W przypadku niezgodności pojawia się komunikat w oknie z ostrzeżeniami.</translation>
    </message>
    <message>
        <source>Toggle the validity check of place markers, i.e. whether %1, %2, ... are used consistently in the source text and translation text. If the check fails, a message is shown in the warnings window.</source>
        <translation>Przełącz sprawdzanie zgodności znaczników, tzn. czy: %1, %2, ... są spójnie użyte w tekście źródłowym i tłumaczeniu. W przypadku niezgodności pojawia się komunikat w oknie z ostrzeżeniami.</translation>
    </message>
    <message>
        <source>Ctrl+J</source>
        <translation>Ctrl+J</translation>
    </message>
    <message>
        <source>Ctrl+Shift+J</source>
        <translation>Ctrl+Shift+J</translation>
    </message>
    <message>
        <source>Previous unfinished item</source>
        <translation>Poprzedni nieukończony element</translation>
    </message>
    <message>
        <source>Next unfinished item</source>
        <translation>Następny nieukończony element</translation>
    </message>
    <message>
        <source>Move to previous item</source>
        <translation>Przejdź do poprzedniego elementu</translation>
    </message>
    <message>
        <source>Next item</source>
        <translation>Następny element</translation>
    </message>
    <message>
        <source>Mark item as done and move to the next unfinished item</source>
        <translation>Oznacz element jako ukończony i przejdź do następnego nieukończonego elementu</translation>
    </message>
    <message>
        <source>Copies the source text into the translation field</source>
        <translation>Kopiuje tekst źródłowy do pola z tłumaczeniem</translation>
    </message>
    <message>
        <source>Toggle the validity check of accelerators</source>
        <translation>Przełącz sprawdzanie zgodności klawiszy skrótów</translation>
    </message>
    <message>
        <source>Toggle the validity check of ending punctuation</source>
        <translation>Przełącz sprawdzanie zgodności końcowych znaków interpunkcyjnych</translation>
    </message>
    <message>
        <source>Toggle checking that phrase suggestions are used</source>
        <translation>Przełącz sprawdzanie czy użyto zasugerowanego wyrażenia</translation>
    </message>
    <message>
        <source>Toggle the validity check of place markers</source>
        <translation>Przełącz sprawdzanie zgodności znaczników</translation>
    </message>
    <message>
        <source>Create a Qt message file suitable for released applications from the current message file. The filename will automatically be determined from the name of the TS file.</source>
        <translation>Utwórz binarny plik &quot;.qm&quot; z tłumaczeniami na podstawie bieżącego tłumaczenia, gotowy do użycia w aplikacjach. Nazwa pliku będzie automatycznie określona na podstawie nazwy pliku &quot;.ts&quot; z bieżącym tłumaczeniem.</translation>
    </message>
    <message>
        <source>Length Variants</source>
        <translation>Warianty tłumaczeń</translation>
    </message>
    <message>
        <source>&amp;Zoom</source>
        <translation>&amp;Powiększenie</translation>
    </message>
    <message>
        <source>Display information about the Qt toolkit by Digia.</source>
        <translation>Pokaż informacje o Qt.</translation>
    </message>
    <message>
        <source>Visualize whitespace</source>
        <translation>Pokazuj białe znaki</translation>
    </message>
    <message>
        <source>Toggle visualize whitespace in editors</source>
        <translation>Przełącza pokazywanie białych znaków w edytorach</translation>
    </message>
    <message>
        <source>Increase</source>
        <translation>Zwiększ</translation>
    </message>
    <message>
        <source>Ctrl++</source>
        <translation>Ctrl++</translation>
    </message>
    <message>
        <source>Decrease</source>
        <translation>Zmniejsz</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>Reset to default</source>
        <translation>Przywróć domyślne</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
</context>
<context>
    <name>MessageEditor</name>
    <message>
        <source></source>
        <comment>This is the right panel of the main window.</comment>
        <translation></translation>
    </message>
    <message>
        <source>Russian</source>
        <translation>rosyjski</translation>
    </message>
    <message>
        <source>German</source>
        <translation>niemiecki</translation>
    </message>
    <message>
        <source>Japanese</source>
        <translation>japoński</translation>
    </message>
    <message>
        <source>French</source>
        <translation>francuski</translation>
    </message>
    <message>
        <source>Polish</source>
        <translation>polski</translation>
    </message>
    <message>
        <source>Chinese</source>
        <translation>chiński</translation>
    </message>
    <message>
        <source>This whole panel allows you to view and edit the translation of some source text.</source>
        <translation>Ten panel pozwala na podgląd i redagowanie tłumaczenia tekstu źródłowego.</translation>
    </message>
    <message>
        <source>Source text</source>
        <translation>Tekst źródłowy</translation>
    </message>
    <message>
        <source>This area shows the source text.</source>
        <translation>W tym obszarze wyświetlany jest tekst źródłowy.</translation>
    </message>
    <message>
        <source>Source text (Plural)</source>
        <translation>Tekst źródłowy (liczba mnoga)</translation>
    </message>
    <message>
        <source>This area shows the plural form of the source text.</source>
        <translation>W tym obszarze wyświetlana jest forma mnoga źródłowego tekstu.</translation>
    </message>
    <message>
        <source>Developer comments</source>
        <translation>Komentarze programisty</translation>
    </message>
    <message>
        <source>This area shows a comment that may guide you, and the context in which the text occurs.</source>
        <translation>W tym obszarze wyświetlany jest komentarz oraz kontekst, w którym dany tekst wystąpił.</translation>
    </message>
    <message>
        <source>Here you can enter comments for your own use. They have no effect on the translated applications.</source>
        <translation>Tutaj można wprowadzić komentarze na własny użytek. One nie mają wpływu na przetłumaczoną aplikację.</translation>
    </message>
    <message>
        <source>%1 translation (%2)</source>
        <translation>Tłumaczenie na język %1 (%2)</translation>
    </message>
    <message>
        <source>This is where you can enter or modify the translation of the above source text.</source>
        <translation>Tutaj można wprowadzić lub zmodyfikować tłumaczenie tekstu źródłowego.</translation>
    </message>
    <message>
        <source>%1 translation</source>
        <translation>Tłumaczenie na język %1</translation>
    </message>
    <message>
        <source>%1 translator comments</source>
        <translation>Komentarze tłumacza (język %1).</translation>
    </message>
    <message>
        <source>&apos;%1&apos;
Line: %2</source>
        <translation>&apos;%1&apos;
Linia: %2</translation>
    </message>
</context>
<context>
    <name>MessageModel</name>
    <message>
        <source>Completion status for %1</source>
        <translation>Stan ukończenia dla %1</translation>
    </message>
    <message>
        <source>&lt;file header&gt;</source>
        <translation>&lt;nagłówek pliku&gt;</translation>
    </message>
    <message>
        <source>&lt;context comment&gt;</source>
        <translation>&lt;komentarz kontekstu&gt;</translation>
    </message>
    <message>
        <source>&lt;unnamed context&gt;</source>
        <translation>nienazwany kontekst</translation>
    </message>
</context>
<context>
    <name>MsgEdit</name>
    <message>
        <source></source>
        <comment>This is the right panel of the main window.</comment>
        <translation></translation>
    </message>
</context>
<context>
    <name>PhraseBook</name>
    <message>
        <source>Parse error at line %1, column %2 (%3).</source>
        <translation>Błąd parsowania w linii %1, w kolumnie %2 (%3).</translation>
    </message>
</context>
<context>
    <name>PhraseBookBox</name>
    <message>
        <source>(New Entry)</source>
        <translation>(Nowe wyrażenie)</translation>
    </message>
    <message>
        <source>%1[*] - Qt Linguist</source>
        <translation>%1[*] - Qt Linguist</translation>
    </message>
    <message>
        <source>Cannot save phrase book &apos;%1&apos;.</source>
        <translation>Nie można zachować książki wyrażeń &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>Click here to add the phrase to the phrase book.</source>
        <translation>Kliknij aby dodać wyrażenie do książki.</translation>
    </message>
    <message>
        <source>&amp;New Entry</source>
        <translation>&amp;Nowy wpis</translation>
    </message>
    <message>
        <source>Click here to remove the entry from the phrase book.</source>
        <translation>Kliknij tutaj aby usunąć wpis z książki.</translation>
    </message>
    <message>
        <source>&amp;Remove Entry</source>
        <translation>&amp;Usuń wpis</translation>
    </message>
    <message>
        <source>Settin&amp;gs...</source>
        <translation>&amp;Ustawienia</translation>
    </message>
    <message>
        <source>Click here to close this window.</source>
        <translation>Kliknij tutaj aby zamknąć to okno.</translation>
    </message>
    <message>
        <source>Click here to save the changes made.</source>
        <translation>Kliknij tutaj aby zachować wprowadzone zmiany.</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zamknij</translation>
    </message>
    <message>
        <source>&amp;Definition:</source>
        <translation>&amp;Definicja:</translation>
    </message>
    <message>
        <source>Edit Phrase Book</source>
        <translation>Edytuj książkę wyrażeń</translation>
    </message>
    <message>
        <source>Qt Linguist</source>
        <translation>Qt Linguist</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Zachowaj</translation>
    </message>
    <message>
        <source>S&amp;ource phrase:</source>
        <translation>Wyrażenie źródł&amp;owe:</translation>
    </message>
    <message>
        <source>This window allows you to add, modify, or delete entries in a phrase book.</source>
        <translation>To okno pozwala na dodawanie, modyfikowanie i usuwanie wpisów w książce.</translation>
    </message>
    <message>
        <source>This is a definition for the source phrase.</source>
        <translation>To jest definicja wyrażenia źródłowego.</translation>
    </message>
    <message>
        <source>This is the phrase in the source language.</source>
        <translation>To jest wyrażenie zapisane w języku źródłowym.</translation>
    </message>
    <message>
        <source>This is the phrase in the target language corresponding to the source phrase.</source>
        <translation>To jest wyrażenie w języku docelowym odpowiadające wyrażeniu w języku źródłowym.</translation>
    </message>
    <message>
        <source>&amp;Translation:</source>
        <translation>&amp;Tłumaczenie:</translation>
    </message>
    <message>
        <source></source>
        <comment>Go to Phrase &gt; Edit Phrase Book... The dialog that pops up is a PhraseBookBox.</comment>
        <translation></translation>
    </message>
</context>
<context>
    <name>PhraseModel</name>
    <message>
        <source>Definition</source>
        <translation>Definicja</translation>
    </message>
    <message>
        <source>Source phrase</source>
        <translation>Wyrażenie źródłowe</translation>
    </message>
    <message>
        <source>Translation</source>
        <translation>Tłumaczenie</translation>
    </message>
</context>
<context>
    <name>PhraseView</name>
    <message>
        <source>Insert</source>
        <translation>Wstaw</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Edycja</translation>
    </message>
    <message>
        <source>Guess (%1)</source>
        <translation>Podpowiedź (%1)</translation>
    </message>
    <message>
        <source>Guess</source>
        <translation>Podpowiedź</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Translation files (%1);;</source>
        <translation>Pliki z tłumaczeniami (%1);;</translation>
    </message>
    <message>
        <source>All files (*)</source>
        <translation>Wszystkie pliki (*)</translation>
    </message>
    <message>
        <source>Qt Linguist</source>
        <translation>Qt Linguist</translation>
    </message>
</context>
<context>
    <name>SourceCodeView</name>
    <message>
        <source>&lt;i&gt;Source code not available&lt;/i&gt;</source>
        <translation>&lt;i&gt;Kod źródłowy nie jest dostępny&lt;/i&gt;</translation>
    </message>
    <message>
        <source>&lt;i&gt;File %1 not available&lt;/i&gt;</source>
        <translation>&lt;i&gt;Plik %1 nie jest dostępny&lt;/i&gt;</translation>
    </message>
    <message>
        <source>&lt;i&gt;File %1 not readable&lt;/i&gt;</source>
        <translation>&lt;i&gt;Nie można odczytać pliku %1&lt;/i&gt;</translation>
    </message>
</context>
<context>
    <name>Statistics</name>
    <message>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <source>Characters:</source>
        <translation>Znaków:</translation>
    </message>
    <message>
        <source>Characters (with spaces):</source>
        <translation>Znaków (ze spacjami):</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Źródło</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>Statystyki</translation>
    </message>
    <message>
        <source>Translation</source>
        <translation>Tłumaczenie</translation>
    </message>
    <message>
        <source>Words:</source>
        <translation>Słów:</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zamknij</translation>
    </message>
</context>
<context>
    <name>TrWindow</name>
    <message>
        <source></source>
        <comment>This is the application&apos;s main window.</comment>
        <translation></translation>
    </message>
</context>
<context>
    <name>TranslateDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <source>Click here to close this window.</source>
        <translation>Kliknij tutaj aby zamknąć to okno.</translation>
    </message>
    <message>
        <source>Click here to find the next occurrence of the text you typed in.</source>
        <translation>Kliknij tutaj aby znaleźć następne wystąpienie wprowadzonego tekstu.</translation>
    </message>
    <message>
        <source>Find Next</source>
        <translation>Znajdź następny</translation>
    </message>
    <message>
        <source>Find &amp;source text:</source>
        <translation>Szukaj tek&amp;stu źródłowego:</translation>
    </message>
    <message>
        <source>Mark new translation as &amp;finished</source>
        <translation>Zaznacz nowe tłumaczenie jako &amp;zrobione</translation>
    </message>
    <message>
        <source>Match &amp;case</source>
        <translation>Uwzględniaj &amp;wielkość liter</translation>
    </message>
    <message>
        <source>Search options</source>
        <translation>Opcje szukania</translation>
    </message>
    <message>
        <source>Texts such as &apos;TeX&apos; and &apos;tex&apos; are considered as different when checked.</source>
        <translation>Jeśli zaznaczone, teksty &apos;TeX&apos; oraz &apos;tex&apos; są interpretowane jako różne.</translation>
    </message>
    <message>
        <source>This window allows you to search for some text in the translation source file.</source>
        <translation>To okno pozwala na szukanie tekstów w pliku źródłowym tłumaczenia.</translation>
    </message>
    <message>
        <source>Translate</source>
        <translation>Przetłumacz</translation>
    </message>
    <message>
        <source>Translate All</source>
        <translation>Przetłumacz wszystko</translation>
    </message>
    <message>
        <source>&amp;Translate to:</source>
        <translation>Prze&amp;tłumacz na:</translation>
    </message>
    <message>
        <source>Type in the text to search for.</source>
        <translation>Wprowadź tekst do wyszukania.</translation>
    </message>
</context>
<context>
    <name>TranslationSettingsDialog</name>
    <message>
        <source>Any Country</source>
        <translation>Dowolny kraj</translation>
    </message>
    <message>
        <source>Settings for &apos;%1&apos; - Qt Linguist</source>
        <translation>Ustawienia dla &apos;%1&apos; - Qt Linguist</translation>
    </message>
    <message>
        <source>Source language</source>
        <translation>Język źródłowy</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Język</translation>
    </message>
    <message>
        <source>Country/Region</source>
        <translation>Kraj/Region</translation>
    </message>
    <message>
        <source>Target language</source>
        <translation>Język docelowy</translation>
    </message>
</context>
</TS>
